/**
 *    Copyright (C) 2024 Graham Leggett <minfrin@sharp.fm>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

/*
 * redwax_unbound - DNS server access routines.
 *
 */

#ifndef REDWAX_UNBOUND_H_
#define REDWAX_UNBOUND_H_

#include "config.h"

#if 0
#define REDWAX_DEFAULT_ROOT_KEY "/var/lib/unbound/root.key"
#endif

#define REDWAX_DEFAULT_ROOT_KEY "/opt/local/etc/unbound/root.key"

void redwax_add_default_unbound_hooks(apr_pool_t *pool);

#endif /* REDWAX_UNBOUND_H_ */
